## Subtask Branch Check

**IMPORTANT: This is a subtask within a directory task**

Before proceeding:
1. Check if you're on the parent task branch
2. If not on the correct branch, checkout the parent task branch (should already exist)
3. If the branch doesn't exist, inform the user and ask if you should create it

All subtasks in a directory task work on the same branch iteratively.
